# `BioClients.clinicaltrials`

##  ClinicalTrials.gov

NIH NLM ClinicalTrials.gov REST API client

  * <https://clinicaltrials.gov/>
  * <https://clinicaltrials.gov/api>
  * <https://clinicaltrials.gov/api/gui/ref/api_urls>
